@@ -41,8 +41,6 @@
 
 #define KTEXTEDITOR_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))
 
-#define ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, patch) ((major<<16)|(minor<<8)|(patch))
-
 /* Take any defaults from group settings */
 #if !defined(KTEXTEDITOR_NO_DEPRECATED) && !defined(KTEXTEDITOR_DISABLE_DEPRECATED_BEFORE_AND_AT)
 #  ifdef KF_NO_DEPRECATED
@@ -86,7 +84,7 @@
 #define KTEXTEDITOR_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KTEXTEDITOR_NO_DEPRECATED
-#  define KTEXTEDITOR_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56800
+#  define KTEXTEDITOR_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56a00
 #endif
 #ifdef KTEXTEDITOR_NO_DEPRECATED_WARNINGS
 #  define KTEXTEDITOR_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +94,7 @@
 #  ifdef KTEXTEDITOR_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KTEXTEDITOR_DEPRECATED_WARNINGS_SINCE KTEXTEDITOR_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KTEXTEDITOR_DEPRECATED_WARNINGS_SINCE 0x56800
+#    define KTEXTEDITOR_DEPRECATED_WARNINGS_SINCE 0x56a00
 #  endif
 #endif
 
@@ -105,7 +103,7 @@
 #endif
 
 #ifdef KTEXTEDITOR_DEPRECATED
-#  define KTEXTEDITOR_ENABLE_DEPRECATED_SINCE(major, minor) (ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, 0) > KTEXTEDITOR_DISABLE_DEPRECATED_BEFORE_AND_AT)
+#  define KTEXTEDITOR_ENABLE_DEPRECATED_SINCE(major, minor) (((major<<16)|(minor<<8)) > KTEXTEDITOR_DISABLE_DEPRECATED_BEFORE_AND_AT)
 #else
 #  define KTEXTEDITOR_ENABLE_DEPRECATED_SINCE(major, minor) 0
 #endif
